@@ -7,15 +7,16 @@
 #include "kgamesvgdocument.h"
 #include "kgamesvgdocument_p.h"
 
+// own
+#include <kdegamesprivate_logging.h>
 // KF
 #include <KCompressionDevice>
 // Qt
 #include <QBuffer>
-#include <QDebug>
 #include <QDomElement>
 #include <QDomNode>
 #include <QFile>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QString>
 // Std
 #include <cmath>
@@ -170,8 +171,8 @@ QDomNode KGameSvgDocument::elementById(const QString &attributeValue)
 
 void KGameSvgDocument::load()
 {
-    if (d->m_svgFilename.isNull()) {
-        qCDebug(GAMES_LIB) << "KGameSvgDocument::load(): Filename not specified.";
+    if (d->m_svgFilename.isEmpty()) {
+        qCDebug(KDEGAMESPRIVATE_LOG) << "KGameSvgDocument::load(): Filename not specified.";
         return;
     }
 
@@ -197,7 +198,7 @@ void KGameSvgDocument::load()
 
     if (!setContent(content)) {
         file.close();
-        qCDebug(GAMES_LIB) << "DOM content not set.";
+        qCDebug(KDEGAMESPRIVATE_LOG) << "DOM content not set.";
         return;
     }
     file.close();
@@ -209,7 +210,7 @@ void KGameSvgDocument::load(const QString &svgFilename)
     load();
 }
 
-void KGameSvgDocument::rotate(double degrees, const MatrixOptions &options)
+void KGameSvgDocument::rotate(double degrees, MatrixOptions options)
 {
     QTransform matrix;
 
@@ -222,7 +223,7 @@ void KGameSvgDocument::rotate(double degrees, const MatrixOptions &options)
     setTransformMatrix(matrix, ReplaceCurrentMatrix);
 }
 
-void KGameSvgDocument::translate(int xPixels, int yPixels, const MatrixOptions &options)
+void KGameSvgDocument::translate(int xPixels, int yPixels, MatrixOptions options)
 {
     QTransform matrix;
 
@@ -235,7 +236,7 @@ void KGameSvgDocument::translate(int xPixels, int yPixels, const MatrixOptions &
     setTransformMatrix(matrix, ReplaceCurrentMatrix);
 }
 
-void KGameSvgDocument::shear(double xRadians, double yRadians, const MatrixOptions &options)
+void KGameSvgDocument::shear(double xRadians, double yRadians, MatrixOptions options)
 {
     QTransform matrix;
 
@@ -248,7 +249,7 @@ void KGameSvgDocument::shear(double xRadians, double yRadians, const MatrixOptio
     setTransformMatrix(matrix, ReplaceCurrentMatrix);
 }
 
-void KGameSvgDocument::skew(double xDegrees, double yDegrees, const MatrixOptions &options)
+void KGameSvgDocument::skew(double xDegrees, double yDegrees, MatrixOptions options)
 {
     double xRadians = xDegrees * (M_PI / 180);
     double yRadians = yDegrees * (M_PI / 180);
@@ -256,11 +257,11 @@ void KGameSvgDocument::skew(double xDegrees, double yDegrees, const MatrixOption
     shear(xRadians, yRadians, options);
 }
 
-void KGameSvgDocument::scale(double xFactor, double yFactor, const MatrixOptions &options)
+void KGameSvgDocument::scale(double xFactor, double yFactor, MatrixOptions options)
 {
     QTransform matrix;
     if ((xFactor == 0) || (yFactor == 0)) {
-        qWarning() << "KGameSvgDocument::scale: You cannot scale by zero";
+        qCWarning(KDEGAMESPRIVATE_LOG) << "KGameSvgDocument::scale: You cannot scale by zero";
     }
 
     if (options == ApplyToCurrentMatrix) {
@@ -314,8 +315,7 @@ QString KGameSvgDocument::nodeToSvg() const
     QTextStream str(&s);
     QTextStream str_t(&t);
     QStringList defsAdded;
-    int result = 0;
-    QRegExp rx;
+    QRegularExpression rx;
 
     currentNode().save(str, 1);
     xml = *str.string();
@@ -323,19 +323,19 @@ QString KGameSvgDocument::nodeToSvg() const
     // Find and add any required gradients or patterns
     pattern = QLatin1String("url") + WSP_ASTERISK + OPEN_PARENS + WSP_ASTERISK + QLatin1String("#(.*)") + WSP_ASTERISK + CLOSE_PARENS;
     rx.setPattern(pattern);
-    if (rx.indexIn(xml, result) != -1) {
+    if (rx.match(xml).hasMatch()) {
         QDomNode node, nodeBase;
         QString baseId;
         QDomNode n = def();
 
-        result = 0;
-        while ((result = rx.indexIn(xml, result)) != -1) {
-            // Find the pattern or gradient referenced
-            result += rx.matchedLength();
-            if (!defsAdded.contains(rx.cap(1))) {
-                node = d->findElementById(QStringLiteral("id"), rx.cap(1), n);
+        QRegularExpressionMatchIterator i = rx.globalMatch(xml);
+        while (i.hasNext()) {
+            QRegularExpressionMatch match = i.next();
+            const QString id = match.captured(1);
+            if (!defsAdded.contains(id)) {
+                node = d->findElementById(QStringLiteral("id"), id, n);
                 node.save(str_t, 1);
-                defsAdded.append(rx.cap(1));
+                defsAdded.append(id);
             }
 
             // Find the gradient the above gradient is based on
@@ -408,10 +408,8 @@ void KGameSvgDocument::setTransform(const QString &transformAttribute)
 QHash<QString, QString> KGameSvgDocument::styleProperties() const
 {
     QHash<QString, QString> stylePropertiesHash;
-    QStringList styleProperties, keyValuePair;
-    QString styleProperty;
 
-    styleProperties = style().split(QLatin1Char(';'));
+    QList<QStringView> styleProperties = QStringView(style()).split(QLatin1Char(';'));
 
     /* The style attr may have a trailing semi-colon.  If it does, split()
      * gives us an empty final element.  Remove it or we get 'index out of range' errors
@@ -423,10 +421,9 @@ QHash<QString, QString> KGameSvgDocument::styleProperties() const
         d->setStyleHasTrailingSemicolon(false);
     }
 
-    for (int i = 0; i < styleProperties.size(); i++) {
-        styleProperty = styleProperties.at(i);
-        keyValuePair = styleProperty.split(QLatin1Char(':'));
-        stylePropertiesHash.insert(keyValuePair.at(0), keyValuePair.at(1));
+    for (const QStringView &styleProperty : std::as_const(styleProperties)) {
+        const QList<QStringView> keyValuePair = styleProperty.split(QLatin1Char(':'));
+        stylePropertiesHash.insert(keyValuePair.at(0).toString(), keyValuePair.at(1).toString());
     }
     return stylePropertiesHash;
 }
@@ -434,15 +431,14 @@ QHash<QString, QString> KGameSvgDocument::styleProperties() const
 void KGameSvgDocument::setStyleProperties(const QHash<QString, QString> &_styleProperties, const StylePropertySortOptions &options)
 {
     QHash<QString, QString> styleProperties = _styleProperties;
-    QString styleBuffer, property;
+    QString styleBuffer;
 
     d->m_inkscapeOrder << QStringLiteral("fill") << QStringLiteral("fill-opacity") << QStringLiteral("fill-rule") << QStringLiteral("stroke")
                        << QStringLiteral("stroke-width") << QStringLiteral("stroke-linecap") << QStringLiteral("stroke-linejoin")
                        << QStringLiteral("stroke-miterlimit") << QStringLiteral("stroke-dasharray") << QStringLiteral("stroke-opacity");
 
     if (options == UseInkscapeOrder) {
-        for (int i = 0; i < d->m_inkscapeOrder.size(); i++) {
-            property = d->m_inkscapeOrder.at(i);
+        for (const QString &property : std::as_const(d->m_inkscapeOrder)) {
             if (styleProperties.contains(property)) {
                 styleBuffer += property + QLatin1Char(':') + styleProperties.take(property) + QLatin1Char(';');
             } else {
@@ -481,9 +477,8 @@ QTransform KGameSvgDocument::transformMatrix() const
      *
      * For all the gory details, see http://www.w3.org/TR/SVG/coords.html#TransformAttribute
      */
-    QRegExp rx;
+    QRegularExpression rx;
     QString transformAttribute;
-    int result;
     int i = 0;
     QTransform baseMatrix = QTransform();
 
@@ -494,8 +489,8 @@ QTransform KGameSvgDocument::transformMatrix() const
     transformAttribute = transformAttribute.trimmed();
 
     rx.setPattern(TRANSFORMS);
-    if (!rx.exactMatch(transformAttribute)) {
-        qWarning() << "Transform attribute seems to be invalid. Check your SVG file.";
+    if (!rx.match(transformAttribute).hasMatch()) {
+        qCWarning(KDEGAMESPRIVATE_LOG) << "Transform attribute seems to be invalid. Check your SVG file.";
         return QTransform();
     }
 
@@ -503,54 +498,55 @@ QTransform KGameSvgDocument::transformMatrix() const
 
     while (transformAttribute.size() > 0 && i < 32) // 32 is an arbitrary limit for the number of transforms for a single node
     {
-        result = rx.indexIn(transformAttribute);
+        QRegularExpressionMatch match = rx.match(transformAttribute);
+        int result = match.capturedStart();
         if (result != -1) // Found left-most transform
         {
-            if (rx.cap(1) == QLatin1String("matrix")) {
+            if (match.captured(1) == QLatin1String("matrix")) {
                 // If the first transform found is a matrix, use it as the base,
                 // else we use a null matrix.
                 if (i == 0) {
-                    baseMatrix = QTransform(rx.cap(2).toDouble(),
-                                            rx.cap(3).toDouble(),
-                                            rx.cap(4).toDouble(),
-                                            rx.cap(5).toDouble(),
-                                            rx.cap(6).toDouble(),
-                                            rx.cap(7).toDouble());
+                    baseMatrix = QTransform(match.captured(2).toDouble(),
+                                            match.captured(3).toDouble(),
+                                            match.captured(4).toDouble(),
+                                            match.captured(5).toDouble(),
+                                            match.captured(6).toDouble(),
+                                            match.captured(7).toDouble());
                 } else {
-                    baseMatrix = QTransform(rx.cap(2).toDouble(),
-                                            rx.cap(3).toDouble(),
-                                            rx.cap(4).toDouble(),
-                                            rx.cap(5).toDouble(),
-                                            rx.cap(6).toDouble(),
-                                            rx.cap(7).toDouble())
+                    baseMatrix = QTransform(match.captured(2).toDouble(),
+                                            match.captured(3).toDouble(),
+                                            match.captured(4).toDouble(),
+                                            match.captured(5).toDouble(),
+                                            match.captured(6).toDouble(),
+                                            match.captured(7).toDouble())
                         * baseMatrix;
                 }
             }
 
-            if (rx.cap(8) == QLatin1String("translate")) {
-                double x = rx.cap(9).toDouble();
-                double y = rx.cap(10).toDouble();
-                if (rx.cap(10).isEmpty()) // y defaults to zero per SVG standard
+            if (match.captured(8) == QLatin1String("translate")) {
+                double x = match.captured(9).toDouble();
+                double y = match.captured(10).toDouble();
+                if (match.captured(10).isEmpty()) // y defaults to zero per SVG standard
                 {
                     y = 0;
                 }
                 baseMatrix = baseMatrix.translate(x, y);
             }
 
-            if (rx.cap(11) == QLatin1String("scale")) {
-                double x = rx.cap(12).toDouble();
-                double y = rx.cap(12).toDouble();
-                if (rx.cap(13).isEmpty()) // y defaults to x per SVG standard
+            if (match.captured(11) == QLatin1String("scale")) {
+                double x = match.captured(12).toDouble();
+                double y = match.captured(12).toDouble();
+                if (match.captured(13).isEmpty()) // y defaults to x per SVG standard
                 {
                     y = x;
                 }
                 baseMatrix = baseMatrix.scale(x, y);
             }
 
-            if (rx.cap(14) == QLatin1String("rotate")) {
-                double a = rx.cap(15).toDouble();
-                double cx = rx.cap(16).toDouble();
-                double cy = rx.cap(17).toDouble();
+            if (match.captured(14) == QLatin1String("rotate")) {
+                double a = match.captured(15).toDouble();
+                double cx = match.captured(16).toDouble();
+                double cy = match.captured(17).toDouble();
 
                 if ((cx > 0) || (cy > 0)) // rotate around point (cx, cy)
                 {
@@ -562,22 +558,22 @@ QTransform KGameSvgDocument::transformMatrix() const
                 }
             }
 
-            if (rx.cap(18) == QLatin1String("skewX")) {
-                baseMatrix = baseMatrix.shear(rx.cap(19).toDouble() * (M_PI / 180), 0);
+            if (match.captured(18) == QLatin1String("skewX")) {
+                baseMatrix = baseMatrix.shear(match.captured(19).toDouble() * (M_PI / 180), 0);
             }
 
-            if (rx.cap(20) == QLatin1String("skewY")) {
-                baseMatrix = baseMatrix.shear(0, rx.cap(21).toDouble() * (M_PI / 180));
+            if (match.captured(20) == QLatin1String("skewY")) {
+                baseMatrix = baseMatrix.shear(0, match.captured(21).toDouble() * (M_PI / 180));
             }
         }
-        transformAttribute = transformAttribute.mid(rx.matchedLength() + result);
+        transformAttribute = transformAttribute.mid(match.capturedLength() + result);
         i++;
     }
 
     return baseMatrix;
 }
 
-void KGameSvgDocument::setTransformMatrix(QTransform &matrix, const MatrixOptions &options)
+void KGameSvgDocument::setTransformMatrix(QTransform &matrix, MatrixOptions options)
 {
     QString transformBuffer, tmp;
     QTransform null = QTransform();
@@ -632,7 +628,7 @@ QDomNode KGameSvgDocumentPrivate::findElementById(const QString &attributeName,
     }
     if (!node.firstChild().isNull() && !node.nextSibling().isNull()) {
         // Do Nothing
-        // qCDebug(GAMES_LIB) << "No children or siblings.";
+        // qCDebug(KDEGAMESPRIVATE_LOG) << "No children or siblings.";
     }
 
     // Matching node not found, so return a null node.
